/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Thunderbird
 *
 * The Initial Developer of the Original Code is
 *   Mozilla Messaging
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Jim Porter <squibblyflabbetydoo@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* styles for the attachment list */

.attachmentcell-icon {
  padding: 1px;
}

.attachmentcell-name,
.attachmentcell-size {
  padding-top: 1px;
}

.attachmentcell-size {
  color: GrayText;
}

attachmentlist[orient="horizontal"] > attachmentitem {
  pointer-events: none;
}

attachmentlist[orient="horizontal"] .attachmentcell-icon,
attachmentlist[orient="horizontal"] .attachmentcell-nameselection {
  pointer-events: auto;
}

attachmentlist:focus > attachmentitem[selected="true"][current="true"] .attachmentcell-nameselection {
  outline: 1px dotted #F3D982;
}

attachmentlist:focus > attachmentitem[current="true"] .attachmentcell-nameselection {
  outline: 1px dotted;
  outline-offset: -1px;
}

attachmentitem[selected="true"] .attachmentcell-nameselection {
  background-color: -moz-CellHighlight;
  color: -moz-CellHighlightText;
}

attachmentlist:focus > attachmentitem[selected="true"] .attachmentcell-nameselection {
  background-color: Highlight;
  color: HighlightText;
}

attachmentitem[selected="true"] .attachmentcell-icon {
  filter: url("chrome://messenger/skin/imageFilters.svg#selected");
}

attachmentlist:focus > attachmentitem[selected="true"] .attachmentcell-icon {
  filter: url("chrome://messenger/skin/imageFilters.svg#selected-focus");
}
