%include folderPane.css

@media all and (-moz-windows-default-theme) {
  treechildren::-moz-tree-cell-text(folderNameCol, biffState-NewMail, isServer-true, selected),
  treechildren::-moz-tree-cell-text(folderNameCol, newMessages-true, selected),
  treechildren::-moz-tree-cell-text(folderNameCol, specialFolder-Inbox, newMessages-true, selected) {
    color: -moz-hyperlinktext;
  }
  
  treechildren::-moz-tree-cell-text(folderNameCol, biffState-NewMail, isServer-true, selected, focus),
  treechildren::-moz-tree-cell-text(folderNameCol, newMessages-true, selected, focus),
  treechildren::-moz-tree-cell-text(folderNameCol, specialFolder-Inbox, newMessages-true, selected, focus) {
    color: -moz-hyperlinktext;
  }
}
